@@ -1,4 +1,5 @@
 from wraptor.context.maybe import maybe
 from wraptor.context.throttle import throttle
+from wraptor.context.timer import timer
 
-__all__ = ['maybe', 'throttle']
+__all__ = ['maybe', 'throttle', 'timer']
