@@ -1,4 +1,4 @@
-from wraptor.decorators import *
+from wraptor.decorators import timeout, throttle, memoize
 import pytest
 
 with_decorators = pytest.mark.parametrize("decorator", [
@@ -7,8 +7,9 @@ with_decorators = pytest.mark.parametrize("decorator", [
 
 @with_decorators
 def test_called_with_args(decorator):
-    test_args = [1,2,[1,2,3],{'asdf':5}]
-    test_kwargs = {'a': 1, 'b': [1,2,3]}
+    test_args = [1, 2, [1, 2, 3], { 'asdf': 5 }]
+    test_kwargs = { 'a': 1, 'b': [1, 2, 3] }
+
     @decorator()
     def fn(*args, **kwargs):
         assert tuple(test_args) == args
